check_sinks_exist

Function check_sinks_exist 

pub(super) async fn check_sinks_exist(
    client: &Client,
    sinks: &BTreeSet<ObjectId>,
) -> Result<BTreeSet<ObjectId>, ConnectionError>
Check which sinks from the given set exist in the database.

Returns a BTreeSet of ObjectIds for sinks that already exist. Used during apply to skip creating sinks that already exist (like tables).