find_sinks_depending_on_schemas

Function find_sinks_depending_on_schemas 

pub(super) async fn find_sinks_depending_on_schemas(
    client: &Client,
    schemas: &[SchemaQualifier],
) -> Result<Vec<DependentSink>, ConnectionError>
Find sinks that depend on objects in the specified schemas.

This is used during apply to identify sinks that need to be repointed before old schemas are dropped with CASCADE. Only returns sinks whose upstream object (FROM clause) is in one of the specified schemas.