get_default_privilege_grants_for_named_object

Function get_default_privilege_grants_for_named_object 

async fn get_default_privilege_grants_for_named_object(
    client: &Client,
    catalog_table: &str,
    name: &str,
    object_type: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>
Get default privilege grants for a named infrastructure object (cluster, network policy).

Queries mz_default_privileges to find grants that would be auto-applied to the given object based on its owner and any PUBLIC default privileges. These grants should be protected from revocation during reconciliation.