pub(super) async fn get_default_privilege_grants_for_database_object(
client: &Client,
catalog_table: &str,
database: &str,
schema: &str,
name: &str,
object_type: &str,
) -> Result<Vec<ObjectGrant>, ConnectionError>Expand description
Get default privilege grants for a database object (table, source, secret, connection).
Queries mz_default_privileges to find grants that would be auto-applied
to the given object based on its owner, database, schema, and any PUBLIC
default privileges. These grants should be protected from revocation.